.. webhaak documentation master file, created by
   sphinx-quickstart on Wed Feb 20 22:37:46 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to webhaak's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Introduction <README>
   exampleconfig

   apiDoc <webhaak>

   CHANGELOG


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
